from .codes import (
    red_darker,
    red_dark,
    red,
    red_light,
    red_lighter,
    pink_darker,
    pink_dark,
    pink,
    pink_light,
    pink_lighter,
    purple_darker,
    purple_dark,
    purple,
    purple_light,
    purple_lighter,
    deep_purple_darker,
    deep_purple_dark,
    deep_purple,
    deep_purple_light,
    deep_purple_lighter,
    indigo_darker,
    indigo_dark,
    indigo,
    indigo_light,
    indigo_lighter,
    blue_darker,
    blue_dark,
    blue,
    blue_light,
    blue_lighter,
    light_blue_darker,
    light_blue_dark,
    light_blue,
    light_blue_light,
    light_blue_lighter,
    cyan_darker,
    cyan_dark,
    cyan,
    cyan_light,
    cyan_lighter,
    teal_darker,
    teal_dark,
    teal,
    teal_light,
    teal_lighter,
    green_darker,
    green_dark,
    green,
    green_light,
    green_lighter,
    light_green_darker,
    light_green_dark,
    light_green,
    light_green_light,
    light_green_lighter,
    lime_darker,
    lime_dark,
    lime,
    lime_light,
    lime_lighter,
    yellow_darker,
    yellow_dark,
    yellow,
    yellow_light,
    yellow_lighter,
    amber_darker,
    amber_dark,
    amber,
    amber_light,
    amber_lighter,
    orange_darker,
    orange_dark,
    orange,
    orange_light,
    orange_lighter,
    salmon_darker,
    salmon_dark,
    salmon,
    salmon_light,
    salmon_lighter,
    brown_darker,
    brown_dark,
    brown,
    brown_light,
    brown_lighter,
    grey_darker,
    grey_dark,
    grey,
    grey_light,
    grey_lighter,
    blue_grey_darker,
    blue_grey_dark,
    blue_grey,
    blue_grey_light,
    blue_grey_lighter,
    black,
    white,
)

colors = dict(
    red_darker = red_darker,
    red_dark = red_dark,
    red = red ,
    red_light = red_light ,
    red_lighter = red_lighter,
    pink_darker = pink_darker,
    pink_dark = pink_dark ,
    pink = pink,
    pink_light = pink_light,
    pink_lighter = pink_lighter,
    purple_darker = purple_darker,
    purple_dark = purple_dark,
    purple = purple,
    purple_light = purple_light,
    purple_lighter = purple_lighter,
    deep_purple_darker = deep_purple_darker,
    deep_purple_dark = deep_purple_dark,
    deep_purple = deep_purple,
    deep_purple_light = deep_purple_light ,
    deep_purple_lighter = deep_purple_lighter ,
    indigo_darker = indigo_darker,
    indigo_dark = indigo_dark,
    indigo = indigo,
    indigo_light = indigo_light,
    indigo_lighter = indigo_lighter,
    blue_darker = blue_darker,
    blue_dark = blue_dark ,
    blue = blue,
    blue_light = blue_light,
    blue_lighter = blue_lighter,
    light_blue_darker = light_blue_darker ,
    light_blue_dark = light_blue_dark ,
    light_blue = light_blue,
    light_blue_light = light_blue_light,
    light_blue_lighter = light_blue_lighter,
    cyan_darker = cyan_darker,
    cyan_dark = cyan_dark ,
    cyan = cyan,
    cyan_light = cyan_light,
    cyan_lighter = cyan_lighter,
    teal_darker = teal_darker,
    teal_dark = teal_dark ,
    teal = teal,
    teal_light = teal_light,
    teal_lighter = teal_lighter,
    green_darker = green_darker,
    green_dark = green_dark,
    green = green ,
    green_light = green_light,
    green_lighter = green_lighter,
    light_green_darker = light_green_darker,
    light_green_dark = light_green_dark,
    light_green = light_green,
    light_green_light = light_green_light ,
    light_green_lighter = light_green_lighter ,
    lime_darker = lime_darker,
    lime_dark = lime_dark ,
    lime = lime,
    lime_light = lime_light,
    lime_lighter = lime_lighter,
    yellow_darker = yellow_darker,
    yellow_dark = yellow_dark,
    yellow = yellow,
    yellow_light = yellow_light,
    yellow_lighter = yellow_lighter,
    amber_darker = amber_darker,
    amber_dark = amber_dark,
    amber = amber ,
    amber_light = amber_light,
    amber_lighter = amber_lighter,
    orange_darker = orange_darker,
    orange_dark = orange_dark,
    orange = orange,
    orange_light = orange_light,
    orange_lighter = orange_lighter,
    salmon_darker = salmon_darker,
    salmon_dark = salmon_dark,
    salmon = salmon,
    salmon_light = salmon_light ,
    salmon_lighter = salmon_lighter ,
    brown_darker = brown_darker,
    brown_dark = brown_dark,
    brown = brown ,
    brown_light = brown_light,
    brown_lighter = brown_lighter,
    grey_darker = grey_darker,
    grey_dark = grey_dark ,
    grey = grey,
    grey_light = grey_light,
    grey_lighter = grey_lighter,
    blue_grey_darker = blue_grey_darker ,
    blue_grey_dark = blue_grey_dark ,
    blue_grey = blue_grey ,
    blue_grey_light = blue_grey_light,
    blue_grey_lighter = blue_grey_lighter,
    black = black ,
    white = white ,
)